#!/bin/bash

# Set version
version=20.04

# Create package lists
for image in \
  "core:${version}" \
  "daskscheduler" \
  "dataverse" \
  "dataverse-postgresql" \
  "dataverse-solr" \
  "geonode" \
  "geoserver" \
  "gitea" \
  "grafana" \
  "httpd" \
  "jupyterhub" \
  "jupyterhub-proxy" \
  "keycloak" \
  "mariadb" \
  "pgadmin" \
  "postgresql" \
  "prometheus" \
  "spark-proxy"
do
  docker run --rm $image apt list --installed | tee $(sed s/:$version// <<< $image).txt
done

for image in "core:${version}" "base:${version}" "jupyterlab"
do
  ssh mercury docker run --rm $image apt list --installed | tee $(sed s/:$version// <<< $image)-mercury.txt
done

for image in "base" "jupyterlab"
do
  ssh jetson-agx-1 docker run --rm registry:5000/$image apt list --installed | tee $image-jetson.txt
done

# Strip keywords
sed -i "s/,automatic//" *.txt
sed -i "s/,local//" *.txt
sed -i "/Listing.../d" *.txt
sed -i "s/ \[installed\]//" *.txt
sed -i "s/ amd64//" *.txt
sed -i "s/ arm64//" *.txt
sed -i "s/ all//" *.txt

